@@ -32,6 +32,7 @@ class Project:
         connection_lookup: dict = {},
         manifest=None,
         commit_hash=None,
+        conversion_errors: list = [],
     ):
         self._models = models
         self._views = self._handle_join_as_duplication(views)
@@ -47,6 +48,7 @@ class Project:
         self._required_access_filter_user_attributes = []
         self._join_graph = None
         self.commit_hash = commit_hash
+        self._conversion_errors = conversion_errors
 
     def __repr__(self):
         text = "models" if len(self._models) != 1 else "model"
@@ -56,6 +58,9 @@ class Project:
         user_str = "" if not self._user else json.dumps(self._user, sort_keys=True)
         return self._content_hash + hash(user_str)
 
+    def id(self):
+        return hash(self)
+
     def refresh_cache(self):
         # Clear LRU Caches
         self.fields.cache_clear()
@@ -270,21 +275,38 @@ class Project:
         return {**extra, "message": error, "line": None, "column": None}
 
     def validate(self, views_must_be_in_topics: bool = False):
-        all_errors = []
+        all_errors = [] + self._conversion_errors
+
+        model_names = [model.name for model in self.models()]
+
+        # Check for duplicate model names
+        duplicate_models = [name for name, count in Counter(model_names).items() if count > 1]
+        for model_name in duplicate_models:
+            return [self._error(f"Duplicate model name: {model_name}. Model names must be unique.")]
+
         for model in self.models():
             try:
                 all_errors.extend(model.collect_errors())
-            except QueryError as e:
+            except (QueryError, AccessDeniedOrDoesNotExistException) as e:
                 # If we have an error building the model, we cannot continue
                 return [self._error(str(e))]
 
+        topic_names = []
         for topic in self.topics():
+            topic_names.append(topic.label)
             try:
                 all_errors.extend(topic.collect_errors())
             except QueryError as e:
                 # If we have an error building the topic, we cannot continue
                 return [self._error(str(e))]
 
+        # Check for duplicate topic names
+        duplicate_topics = [name for name, count in Counter(topic_names).items() if count > 1]
+        for topic_name in duplicate_topics:
+            all_errors.append(
+                self._error(f"Duplicate topic label: {topic_name}. Topic labels must be unique.")
+            )
+
         if views_must_be_in_topics:
             view_names = [v.name for v in self.views()]
             views_in_topics = set([v.name for topic in self.topics() for v in topic._views()])
@@ -417,7 +439,12 @@ class Project:
             )
 
     def models(self) -> list:
-        return [Model(m, project=self) for m in self._models]
+        models = []
+        for m in self._models:
+            model = Model(m, project=self)
+            if self.can_access_model(model):
+                models.append(model)
+        return models
 
     def get_model(self, model_name: str) -> Model:
         try:
@@ -429,11 +456,12 @@ class Project:
                 object_type="model",
             )
 
-    def topics(self) -> list:
+    def topics(self, show_hidden: bool = True) -> list:
         topics = []
         for t in self._topics:
             topic = Topic(t, project=self)
-            if self.can_access_topic(topic):
+            topic_is_visible = show_hidden or topic.hidden is False
+            if self.can_access_topic(topic) and topic_is_visible:
                 topics.append(topic)
         return topics
 
@@ -448,7 +476,8 @@ class Project:
             )
 
     def access_grants(self):
-        return [AccessGrant(g, model=m) for m in self.models() for g in m.access_grants]
+        all_models = [Model(m, project=self) for m in self._models]
+        return [AccessGrant(g, model=m) for m in all_models for g in m.access_grants]
 
     def get_access_grant(self, grant_name: str):
         try:
@@ -460,10 +489,13 @@ class Project:
         return self._can_access_object(dashboard)
 
     def can_access_topic(self, topic: Topic):
-        return self._can_access_object(topic)
+        return self._can_access_object(topic) and self.can_access_model(topic.model)
 
     def can_access_view(self, view: View):
-        return self._can_access_object(view)
+        return self._can_access_object(view) and self.can_access_model(view.model)
+
+    def can_access_model(self, model: Model):
+        return self._can_access_object(model)
 
     def can_access_field(self, field):
         can_access_view = self.can_access_view(field.view)
